package sysImplementation;

public class Playlist {
	private String name;
	private int entries, maxSize;
	private Video[] videoList;

	public Playlist(String name, int maxSize) {
		if (name == null || maxSize < 1) {
			throw new IllegalArgumentException("Invalid param");
		}
		this.name = name;
		this.maxSize = maxSize;
		videoList = new Video[maxSize];
		entries = 0;
	}

	public Playlist addVideo(String title, int duration) {
		if (title == null || duration <= 0) {
			throw new IllegalArgumentException("Invalid param");
		}
		if (entries < maxSize) {
			videoList[entries++] = new Video(title, duration);
		}
		return this;
	}

	public String getName() {
		return name;
	}

	public int getEntries() {
		return entries;
	}

	public int getMaxSize() {
		return maxSize;
	}

	public Video[] getVideoList() {
		Video[] answer = new Video[entries];

		for (int i = 0; i < answer.length; i++) {
			answer[i] = new Video(videoList[i]);
		}

		return answer;
	}

	public boolean findVideo(String title) {
		return findVideoAux(title) != -1;
	}

	public boolean addReview(String title, String review) {
		if (title == null || review == null) {
			throw new IllegalArgumentException("Invalid param");
		}
		int index = findVideoAux(title);

		if (index != -1) {
			videoList[index].addReview(review);
			return true;
		}

		return false;
	}

	public int compareTo(Playlist playlist) {
		int comparison = entries - playlist.entries;
		if (comparison != 0) {
			return comparison;
		} else {
			return name.compareTo(playlist.name);
		}
	}

	public int removeVideos(int lowerLimit, int upperLimit) {
		if (upperLimit < lowerLimit) {
			throw new IllegalArgumentException("Invalid param");
		}
		
		Video[] newList = new Video[maxSize];

		int newIndex = 0;
		for (int i = 0; i < entries; i++) {
			int duration = videoList[i].getDuration();
			if (!(duration >= lowerLimit && duration <= upperLimit)) {
				newList[newIndex++] = videoList[i];
			}
		}

		int oldEntriesNumber = entries;
		if (newIndex != entries) {
			videoList = newList;
			entries = newIndex;
		}

		return oldEntriesNumber - entries;
	}

	private int findVideoAux(String title) {
		if (entries > 0) {
			for (int i = 0; i < entries; i++) {
				if (videoList[i].getTitle().equals(title)) {
					return i;
				}
			}
		}
		return -1;
	}
}
